pub struct DerivationParameters { /* private fields */ }Expand description
Serializable parameters that fully describe a completed key derivation. Can be stored alongside a user record to re-derive the same key later.
Implementations
Sourceimpl DerivationParameters
impl DerivationParameters
Sourcepub fn derive(&self, password: &[u8]) -> Result<SecretKey>
pub fn derive(&self, password: &[u8]) -> Result<SecretKey>
Derives a SecretKey from password using these derivation parameters.
Sourcepub fn compute(&self, password: &[u8]) -> Result<Zeroizing<Vec<u8>>>
pub fn compute(&self, password: &[u8]) -> Result<Zeroizing<Vec<u8>>>
Re-derives raw bytes from a password using the stored algorithm and parameters.
Sourcepub fn output_length(&self) -> usize
pub fn output_length(&self) -> usize
Returns the byte-length of the hash that compute will produce.